@@ -1,8 +1,8 @@
-from rpcdispatcher import RPCDispatcher, rpcmethod
+from .rpcdispatcher import RPCDispatcher, rpcmethod   # noqa
 
 _MAJOR = 0
 _MINOR = 2
-_PATCH = 2
+_PATCH = 3
 
 __version__ = str(_MAJOR) + '.' + str(_MINOR) + '.' + str(_PATCH)
 
