@@ -1,14 +1,20 @@
 import httplib
-import xmlrpclib
+
+try:
+    # Python2
+    from xmlrpclib import SafeTransport, Transport, ProtocolError
+except ImportError:
+    # Python3
+    from xmlrpc.client import SafeTransport, Transport, ProtocolError
 
 
-class CookieTransport(xmlrpclib.SafeTransport):
+class CookieTransport(SafeTransport):
     """
     Overides request add cookies from previous request.
     """
 
     def __init__(self):
-        xmlrpclib.Transport.__init__(self)
+        Transport.__init__(self)
         self.cookie = None
 
     def make_connection(self, host):
@@ -35,11 +41,11 @@ class CookieTransport(xmlrpclib.SafeTransport):
         self.cookie = headers.getheader('set-cookie') or self.cookie
 
         if errcode != 200:
-            raise xmlrpclib.ProtocolError(
+            raise ProtocolError(
                 host + handler,
                 errcode, errmsg,
                 headers
-                )
+            )
 
         # do not print the response body
         self.verbose = False
